==> deepin-screen-recorder_5.9.6.orig.tar.xz: deepin-screen-recorder-5.9.6/translations/deepin-screen-recorder_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl_ES" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Prema na icona da bandexa
ou prema de novo o atallo para deixar de gravar</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Fallou o gardado. Gardao no seu directorio persoal.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Captura de pantalla finalizada</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>seleccionar-área</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gardar en %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Desfacer</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Gravación finalizada</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gardar en %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>A captura de pantalla comezará en %1 segundos</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Insira o texto aquí</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Comezar/Captura de pantalla</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Saír/Gardar</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Debuxar</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Axuste do tamaño</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuracións</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Inicio rápido</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Captura de pantalla da xanela</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Retrasar a captura de pantalla</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Captura de pantalla enteira</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Liña</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lapis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfacer</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Aumente a altura cara arriba</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Aumente a altura cara abaixo</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Aumenta o ancho á esquerda</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Aumenta o ancho á dereita</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Reducir a altura</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Reducir a altura cara abaixo</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Reduce o ancho á esquerda</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Reduce a anchura á dereita</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Amosar atallos</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Iniciar gravación</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcións</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Borroso</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaico</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Encender o son</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Micrófono</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Audio do sistema</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Apagar o son</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Amosar tecla</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Agochar tecla</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Acender Webcam</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Apagar Webcam</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Amosar Premer</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcións</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Liña</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Frecha</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lapis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Gardar en</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imaxes</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Cartafol</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show pointer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Gravacións</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Prema na icona da bandexa
ou prema de novo o atallo para deixar de gravar</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Fallou o gardado. Gardao no seu directorio persoal.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Captura de pantalla finalizada</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>seleccionar-área</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gardar en %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Desfacer</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Gravación finalizada</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gardar en %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>A captura de pantalla comezará en %1 segundos</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Insira o texto aquí</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Comezar/Captura de pantalla</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Saír/Gardar</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Axuste do tamaño</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuracións</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Inicio rápido</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Captura de pantalla da xanela</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Retrasar a captura de pantalla</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Captura de pantalla enteira</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Liña</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lapis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfacer</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Aumente a altura cara arriba</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Aumente a altura cara abaixo</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Aumenta o ancho á esquerda</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Aumenta o ancho á dereita</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Reducir a altura</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Reducir a altura cara abaixo</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Reduce o ancho á esquerda</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Reduce a anchura á dereita</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Amosar atallos</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Iniciar gravación</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcións</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Borroso</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaico</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Encender o son</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Micrófono</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Audio do sistema</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Apagar o son</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Amosar tecla</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Agochar tecla</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Acender Webcam</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Apagar Webcam</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Amosar Premer</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcións</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Liña</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Frecha</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lapis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Gardar en</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imaxes</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Cartafol</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished">Saír</translation>
    </message>
</context>
</TS>
